Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLudovic Henry <ludovic@xamarin.com>2017-02-09 22:57:59 +0300
committerGitHub <noreply@github.com>2017-02-09 22:57:59 +0300
commitecf25101086810b83d9d4d30ee532c3e2b56ec9b (patch)
tree14f4a92fd0ce83d4ae2705bfa0b3fd7fa8843d69 /mcs/class/System/System.Diagnostics
parent12b44a0e9470883a245f2e92af3b8fcc1fc60329 (diff)
[process] Improve error message for inaccessible process (#4354)
Fixes bug https://bugzilla.xamarin.com/show_bug.cgi?id=51561
Diffstat (limited to 'mcs/class/System/System.Diagnostics')
-rw-r--r--mcs/class/System/System.Diagnostics/Process.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/mcs/class/System/System.Diagnostics/Process.cs b/mcs/class/System/System.Diagnostics/Process.cs
index 8423659fdc7..9b3fdf9dc5e 100644
--- a/mcs/class/System/System.Diagnostics/Process.cs
+++ b/mcs/class/System/System.Diagnostics/Process.cs
@@ -331,9 +331,9 @@ namespace System.Diagnostics
process_name = ProcessName_internal (handle);
/* If process_name is _still_ null, assume the process has exited */
if (process_name == null)
- throw new InvalidOperationException ("Process has exited, so the requested information is not available.");
+ throw new InvalidOperationException ("Process has exited or is inaccessible, so the requested information is not available.");
/* Strip the suffix (if it exists) simplistically instead of removing
* any trailing \.???, so we dont get stupid results on sane systems */
@@ -331,9 +331,9 @@ namespace System.Diagnostics
process_name = ProcessName_internal (handle);
- /* If process_name is _still_ null, assume the process has exited */
+ /* If process_name is _still_ null, assume the process has exited or is inaccessible */
if (process_name == null)